# Reasoning Models From Scratch

**Understanding LLM Reasoning by Implementing It From The Ground Up**





- Chapter 1: Introduction
- Chapter 2: Building the Base LLM
- Chapter 3: Evaluating Reasoning
- Chapter 4: Scaling Inference-Compute for Better Reasoning
- Chapter 5: Reinforcement Learning with Verifiable Rewards
- Chapter 6: Distillation for Efficient Reasoning
- Chapter 7: The Reasoning Pipeline and Open Research Challenges
- Appendix A: Exercise Solutions